"""changes

Revision ID: 3382cd293e50
Revises: 6b385de534b7
Create Date: 2022-08-28 00:00:06.142778

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "3382cd293e50"
down_revision = "6b385de534b7"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
