"""made session_id col for session info

Revision ID: de275a6ec226
Revises: 04074343ab1f
Create Date: 2017-08-13 00:36:32.087692

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "de275a6ec226"
down_revision = "04074343ab1f"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("session_info", sa.Column("session_id", sa.Integer(), nullable=False))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("session_info", "session_id")
    # ### end Alembic commands ###
