"""Renamed incorrect umap_id correctly

Revision ID: d36bdd1852b5
Revises: a3f5d5b17c97
Create Date: 2018-09-18 23:17:13.309317

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision = "d36bdd1852b5"
down_revision = "a3f5d5b17c97"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "object_umap_features",
        sa.Column("object_umap_features_id", sa.Integer(), nullable=False),
    )
    op.drop_column("object_umap_features", "object_pca_features_id")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "object_umap_features",
        sa.Column(
            "object_pca_features_id", mysql.INTEGER(display_width=11), nullable=False
        ),
    )
    op.drop_column("object_umap_features", "object_umap_features_id")
    # ### end Alembic commands ###
