"""session_info timestamp as integer

Revision ID: 04074343ab1f
Revises: f0c1aa4b2657
Create Date: 2017-08-13 00:09:28.767522

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "04074343ab1f"
down_revision = "f0c1aa4b2657"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
