"""session_info auto increment

Revision ID: b587da5794d6
Revises: de275a6ec226
Create Date: 2017-08-13 00:42:09.284574

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "b587da5794d6"
down_revision = "de275a6ec226"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
