"""changed pca_object_features id colname and added timestamp added col

Revision ID: 02d94cd8a1ce
Revises: 4fdaad670a35
Create Date: 2018-07-05 20:33:12.997287

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision = "02d94cd8a1ce"
down_revision = "4fdaad670a35"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "object_pca_features",
        sa.Column("object_pca_features_id", sa.Integer(), nullable=False),
    )
    op.add_column(
        "object_pca_features",
        sa.Column("timestamp_added", sa.String(length=10), nullable=False),
    )
    op.drop_column("object_pca_features", "pca_features_id")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "object_pca_features",
        sa.Column("pca_features_id", mysql.INTEGER(display_width=11), nullable=False),
    )
    op.drop_column("object_pca_features", "timestamp_added")
    op.drop_column("object_pca_features", "object_pca_features_id")
    # ### end Alembic commands ###
