"""Added youtube_link column

Revision ID: 55b537e0c4db
Revises: d51287a30494
Create Date: 2017-07-30 11:22:34.921037

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "55b537e0c4db"
down_revision = "d51287a30494"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "videos", sa.Column("youtube_link", sa.String(length=128), nullable=True)
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("videos", "youtube_link")
    # ### end Alembic commands ###
