"""Changed videos.upload_timestamp to videos.timestamp_add_video

Revision ID: 335e48271836
Revises: a25b2b88671d
Create Date: 2017-07-30 17:53:34.021758

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision = "335e48271836"
down_revision = "a25b2b88671d"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "videos", sa.Column("timestamp_add_video", sa.String(length=10), nullable=False)
    )
    op.drop_column("videos", "upload_timestamp")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "videos",
        sa.Column("upload_timestamp", mysql.VARCHAR(length=10), nullable=False),
    )
    op.drop_column("videos", "timestamp_add_video")
    # ### end Alembic commands ###
