"""add haar_cascade table

Revision ID: c4d469256008
Revises: 08a49ff86510
Create Date: 2018-03-20 19:10:40.348304

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "c4d469256008"
down_revision = "08a49ff86510"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "haar_cascades",
        sa.Column("haar_cascade_id", sa.Integer(), nullable=False),
        sa.Column("haar_cascade_name", sa.String(length=32), nullable=False),
        sa.Column("file", sa.String(length=48), nullable=False),
        sa.PrimaryKeyConstraint("haar_cascade_id", "haar_cascade_name", "file"),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("haar_cascades")
    # ### end Alembic commands ###
