"""changes

Revision ID: c103233a6a69
Revises: 3382cd293e50
Create Date: 2022-08-28 00:02:03.942691

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "c103233a6a69"
down_revision = "3382cd293e50"
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
