"""add columns to actors

Revision ID: 1b019da65d4f
Revises: 8fd3900c2c9e
Create Date: 2017-07-29 17:03:30.977180

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "1b019da65d4f"
down_revision = "8fd3900c2c9e"
branch_labels = None
depends_on = None


def upgrade():
    pass


def downgrade():
    pass
