"""misspelt timestamp_add_process

Revision ID: 08a49ff86510
Revises: cc6544d0f3bb
Create Date: 2018-02-14 23:00:43.006672

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision = "08a49ff86510"
down_revision = "cc6544d0f3bb"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "processes",
        sa.Column("timestamp_add_process", sa.String(length=10), nullable=False),
    )
    op.drop_column("processes", "timestamp_add_processes")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "processes",
        sa.Column("timestamp_add_processes", mysql.VARCHAR(length=10), nullable=False),
    )
    op.drop_column("processes", "timestamp_add_process")
    # ### end Alembic commands ###
