"""made episode name nullable

Revision ID: 8ff7642a7c59
Revises: 6906302f0e6e
Create Date: 2017-08-12 00:23:01.049392

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision = "8ff7642a7c59"
down_revision = "6906302f0e6e"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column(
        "episodes",
        "episode_name",
        existing_type=mysql.VARCHAR(length=128),
        nullable=True,
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column(
        "episodes",
        "episode_name",
        existing_type=mysql.VARCHAR(length=128),
        nullable=False,
    )
    # ### end Alembic commands ###
