"""Added boolean to videos indicating download process completion

Revision ID: 9133ec0c2db6
Revises: f54dfed2dafd
Create Date: 2017-08-08 19:34:12.935020

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "9133ec0c2db6"
down_revision = "f54dfed2dafd"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "videos", sa.Column("download_process_complete", sa.Boolean(), nullable=True)
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("videos", "download_process_complete")
    # ### end Alembic commands ###
