"""removed character_labels relationship from videos table

Revision ID: 1263b617af57
Revises: d6ffb5f09ed6
Create Date: 2017-10-30 19:23:09.058365

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "1263b617af57"
down_revision = "d6ffb5f09ed6"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
