"""added dlib face tables

Revision ID: c56cae55295e
Revises: 2a3a19b776c5
Create Date: 2020-06-03 13:53:22.656333

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "c56cae55295e"
down_revision = "2a3a19b776c5"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
