"""test revision

Revision ID: 63fcb6f73f50
Revises:
Create Date: 2017-07-28 23:55:13.910104

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "63fcb6f73f50"
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    pass


def downgrade():
    pass
