"""Added uniqueness to youtube_link column

Revision ID: 522cd0c45168
Revises: 55b537e0c4db
Create Date: 2017-07-30 11:29:48.582700

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "522cd0c45168"
down_revision = "55b537e0c4db"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_unique_constraint(None, "videos", ["youtube_link"])
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, "videos", type_="unique")
    # ### end Alembic commands ###
