"""fixed error in episode faces relationship again

Revision ID: f54dfed2dafd
Revises: 9a3b4cac9346
Create Date: 2017-08-07 22:19:58.298629

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "f54dfed2dafd"
down_revision = "9a3b4cac9346"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
