"""fixed error in episode faces relationship

Revision ID: 9a3b4cac9346
Revises: e1d164c37112
Create Date: 2017-08-07 21:33:34.865387

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "9a3b4cac9346"
down_revision = "e1d164c37112"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
