"""Make series_name column a string column

Revision ID: 8fd3900c2c9e
Revises: bc0978602558
Create Date: 2017-07-29 12:35:15.558688

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "8fd3900c2c9e"
down_revision = "bc0978602558"
branch_labels = None
depends_on = None


def upgrade():
    op.execute("ALTER TABLE series MODIFY series_name VARCHAR(128) NOT NULL")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
