"""add object_pca_features table

Revision ID: 4fdaad670a35
Revises: c4d469256008
Create Date: 2018-07-05 08:20:04.822029

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "4fdaad670a35"
down_revision = "c4d469256008"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "object_pca_features",
        sa.Column("pca_features_id", sa.Integer(), nullable=False),
        sa.Column("object_id", sa.Integer(), nullable=True),
        sa.Column("feature_1", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_2", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_3", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_4", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_5", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_6", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_7", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_8", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_9", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_10", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_11", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_12", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_13", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_14", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_15", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_16", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_17", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_18", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_19", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_20", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_21", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_22", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_23", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_24", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_25", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_26", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_27", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_28", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_29", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_30", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_31", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.Column("feature_32", sa.Numeric(precision=7, scale=6), nullable=False),
        sa.ForeignKeyConstraint(
            ["object_id"],
            ["objects.object_id"],
        ),
        sa.PrimaryKeyConstraint("pca_features_id"),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("object_pca_features")
    # ### end Alembic commands ###
