"""add timestamps added for processes and triggers

Revision ID: 87163b759a86
Revises: 499e890aa148
Create Date: 2018-02-14 22:49:22.775146

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "87163b759a86"
down_revision = "499e890aa148"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "processes",
        sa.Column("timestamp_add_processes", sa.String(length=10), nullable=True),
    )
    op.add_column(
        "triggers",
        sa.Column("timestamp_add_trigger", sa.String(length=10), nullable=True),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("triggers", "timestamp_add_trigger")
    op.drop_column("processes", "timestamp_add_processes")
    # ### end Alembic commands ###
