"""character_labels needs a key col

Revision ID: 27c3ed745239
Revises: 817384c566f4
Create Date: 2017-10-31 21:05:49.454699

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "27c3ed745239"
down_revision = "817384c566f4"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
