"""Added save_name to videos table

Revision ID: a25b2b88671d
Revises: 522cd0c45168
Create Date: 2017-07-30 13:38:57.668644

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "a25b2b88671d"
down_revision = "522cd0c45168"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "videos", sa.Column("save_name", sa.String(length=156), nullable=False)
    )
    op.create_unique_constraint(None, "videos", ["save_name"])
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, "videos", type_="unique")
    op.drop_column("videos", "save_name")
    # ### end Alembic commands ###
