"""added cascade column to objects table

Revision ID: 817384c566f4
Revises: 1263b617af57
Create Date: 2017-10-30 22:14:39.428483

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "817384c566f4"
down_revision = "1263b617af57"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column("objects", sa.Column("object_cascade", sa.Integer(), nullable=False))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("objects", "object_cascade")
    # ### end Alembic commands ###
